==> kubernetes-model-autoscaling-5.0.3-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/MetricStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class MetricStatusBuilder extends MetricStatusFluentImpl<MetricStatusBuilder> implements VisitableBuilder<MetricStatus,MetricStatusBuilder> {

    MetricStatusFluent<?> fluent;
    Boolean validationEnabled;

    public MetricStatusBuilder() {
        this(true);
    }

    public MetricStatusBuilder(Boolean validationEnabled) {
        this(new MetricStatus(), validationEnabled);
    }

    public MetricStatusBuilder(MetricStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public MetricStatusBuilder(MetricStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new MetricStatus(), validationEnabled);
    }

    public MetricStatusBuilder(MetricStatusFluent<?> fluent,MetricStatus instance) {
        this(fluent, instance, true);
    }

    public MetricStatusBuilder(MetricStatusFluent<?> fluent,MetricStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withExternal(instance.getExternal()); 
        fluent.withObject(instance.getObject()); 
        fluent.withPods(instance.getPods()); 
        fluent.withResource(instance.getResource()); 
        fluent.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public MetricStatusBuilder(MetricStatus instance) {
        this(instance,true);
    }

    public MetricStatusBuilder(MetricStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withExternal(instance.getExternal()); 
        this.withObject(instance.getObject()); 
        this.withPods(instance.getPods()); 
        this.withResource(instance.getResource()); 
        this.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public MetricStatus build() {
        MetricStatus buildable = new MetricStatus(fluent.getExternal(),fluent.getObject(),fluent.getPods(),fluent.getResource(),fluent.getType());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        MetricStatusBuilder that = (MetricStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-autoscaling-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/MetricStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class MetricStatusBuilder extends MetricStatusFluentImpl<MetricStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<MetricStatus,MetricStatusBuilder> {

    MetricStatusFluent<?> fluent;
    Boolean validationEnabled;

    public MetricStatusBuilder() {
        this(true);
    }

    public MetricStatusBuilder(Boolean validationEnabled) {
        this(new MetricStatus(), validationEnabled);
    }

    public MetricStatusBuilder(MetricStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public MetricStatusBuilder(MetricStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new MetricStatus(), validationEnabled);
    }

    public MetricStatusBuilder(MetricStatusFluent<?> fluent,MetricStatus instance) {
        this(fluent, instance, true);
    }

    public MetricStatusBuilder(MetricStatusFluent<?> fluent,MetricStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withContainerResource(instance.getContainerResource()); 
        fluent.withExternal(instance.getExternal()); 
        fluent.withObject(instance.getObject()); 
        fluent.withPods(instance.getPods()); 
        fluent.withResource(instance.getResource()); 
        fluent.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public MetricStatusBuilder(MetricStatus instance) {
        this(instance,true);
    }

    public MetricStatusBuilder(MetricStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withContainerResource(instance.getContainerResource()); 
        this.withExternal(instance.getExternal()); 
        this.withObject(instance.getObject()); 
        this.withPods(instance.getPods()); 
        this.withResource(instance.getResource()); 
        this.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public MetricStatus build() {
        MetricStatus buildable = new MetricStatus(fluent.getContainerResource(),fluent.getExternal(),fluent.getObject(),fluent.getPods(),fluent.getResource(),fluent.getType());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        MetricStatusBuilder that = (MetricStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
